Learn R Programming

artfima (version 1.3)

best_glp_models: Best AIC/BIC Models for Specified GLP

Description

This function is used by bestModels

Usage

best_glp_models(z, glp = c("ARTFIMA", "ARFIMA", "ARIMA"), p = 2, q = 2, 
   likAlg = c("exact", "Whittle"))

Arguments

z
time series
glp
glp is equal to one of the following choices: "ARTFIMA", "ARFIMA" or "ARIMA"
p
maximum order of AR component
q
maximum order of MA component
likAlg
likAlg = c("exact", "Whittle")) either "exact" or "Whittle"

Value

  • A list with 4 entries:
  • LLlog-likelihood of models
  • artfima_timetotal time
  • aiclist with best aic models
  • biclist with best bic models
  • Each of the components aic and bic is a list with three components:
  • bestaicbest aic models
  • bestbicModelbest model
  • aicplausability
  • Similarly for the bic component.

See Also

bestModels

Examples

Run this code
#takes about 4 minutes. Checking result for bestmodels()
z<-tseg(1000, "BJARMA11")
ansARIMA <- best_glp_models(z, glp = "ARIMA", p=2, q=2)
ansARFIMA <- best_glp_models(z, glp = "ARFIMA", p=2, q=2)
ansARTFIMA <- best_glp_models(z, glp = "ARTFIMA", p=2, q=2)
ansARIMA$bic$bic
ansARFIMA$bic$bic
ansARTFIMA$bic$bic
bestModels(z)

Run the code above in your browser using DataLab